==> Pyrogram-0.12.0-py3-none-any.whl: pyrogram/api/types/input_media_game.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class InputMediaGame(Object):
    """Attributes:
        ID: ``0xd33f43f3``

    Args:
        id: Either :obj:`InputGameID <pyrogram.api.types.InputGameID>` or :obj:`InputGameShortName <pyrogram.api.types.InputGameShortName>`
    """

    __slots__ = ["id"]

    ID = 0xd33f43f3
    QUALNAME = "InputMediaGame"

    def __init__(self, *, id):
        self.id = id  # InputGame

    @staticmethod
    def read(b: BytesIO, *args) -> "InputMediaGame":
        # No flags
        
        id = Object.read(b)
        
        return InputMediaGame(id=id)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(self.id.write())
        
        return b.getvalue()

==> Pyrogram-0.13.0-py3-none-any.whl: pyrogram/api/types/input_media_game.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class InputMediaGame(Object):
    """Attributes:
        ID: ``0xd33f43f3``

    Parameters:
        id: Either :obj:`InputGameID <pyrogram.api.types.InputGameID>` or :obj:`InputGameShortName <pyrogram.api.types.InputGameShortName>`
    """

    __slots__ = ["id"]

    ID = 0xd33f43f3
    QUALNAME = "types.InputMediaGame"

    def __init__(self, *, id):
        self.id = id  # InputGame

    @staticmethod
    def read(b: BytesIO, *args) -> "InputMediaGame":
        # No flags
        
        id = Object.read(b)
        
        return InputMediaGame(id=id)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(self.id.write())
        
        return b.getvalue()
